@@ -274,9 +274,9 @@ class Report:
             if source_type:
                 e.SubElement(source_elem, "type").text = source_type
             if source_description:
-                e.SubElement(
-                    source_elem, "description"
-                ).text = source_description
+                e.SubElement(source_elem, "description").text = (
+                    source_description
+                )
 
         return host_detail_elem
 
@@ -321,9 +321,9 @@ class Report:
                     result_id = generate_uuid()
                     result = e.Element("result", {"id": result_id})
                     e.SubElement(result, "name").text = f"Result for host {ip}"
-                    e.SubElement(
-                        result, "comment"
-                    ).text = "Imported with gvm-tools"
+                    e.SubElement(result, "comment").text = (
+                        "Imported with gvm-tools"
+                    )
                     e.SubElement(result, "modification_time").text = date_time
                     e.SubElement(result, "creation_time").text = date_time
                     detect_elem = e.Element("detection")
